.. include:: ../BADGES.rst

.. _cltoolbox_documentation:

cltoolbox
=========

This is the home page for cltoolbox.  cltoolbox is a Python library to easily
setup and use a command line interface (CLI) for a Python script.

cltoolbox should work with Python 3.7+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   usage
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
